#
# spec file for package hollywood
#
# Copyright (c) 2021 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


#

Name:           hollywood
Version:        1.21
Release:        bp155.2.9
Summary:        Program to fill the console with Hollywood melodrama technobabble
License:        Apache-2.0 AND CC0-1.0
Group:          Amusements/Toys/Other
URL:            https://launchpad.net/hollywood
Source:         https://launchpad.net/hollywood/trunk/%{version}/+download/hollywood_%{version}.orig.tar.gz#/%{name}-%{version}.tar.gz
# PATCH-FIX-OPENSUSE libexec_fix.patch -- rewrite module paths from /usr/lib/ to /usr/libexec/
Patch0:         libexec_fix.patch
Recommends:     apg
Recommends:     bmon
Recommends:     byobu
# in debian: bsdmainutils
Recommends:     util-linux
Recommends:     ccze
Recommends:     cmatrix
Recommends:     coreutils
Recommends:     htop
Recommends:     jp2a
Recommends:     mlocate
Requires:       moreutils
Recommends:     mplayer
Recommends:     openssh-client
Recommends:     speedometer
Recommends:     tree
Requires:       %name-data
# for /usr/bin/pygmentize
Requires:       python3-Pygments
Requires:       tmux
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildArch:      noarch

%package data
Summary:        Data files for hollywood
License:        CC0-1.0
Group:          Amusements/Toys/Other

%package -n wallstreet
Summary:        Program to fill the console with Wall Street-like news and stats
License:        Apache-2.0
Group:          Amusements/Toys/Other
Recommends:     byobu
Recommends:     caca-utils
Recommends:     newsbeuter
Requires:       perl-base
Recommends:     rsstail
# unavailable
Recommends:     ticker
Requires:       wget
Recommends:     w3m
# unavailable:
Recommends:     jp2a

%description
This utility will split the console into a multiple panes of genuine
technobabble, perfectly suitable for any Hollywood geek melodrama.
It is particularly suitable on any number of computer consoles in the
background of any excellent schlock technothriller.

%description data
Data files needed for the "hollywood" package.

%description -n wallstreet
This utility will split the console into a multiple panes of news
and statistics, like any good computer screen on Wall Street.

%prep
%setup -q
%patch0 -p0

%build

%install
install -Dm 0755 -t %buildroot/%_bindir bin/hollywood
install -Dm 0755 -t %buildroot/%_libexecdir/hollywood/ lib/hollywood/*
install -Dm 0644 -t %buildroot/%_mandir/man1/ share/man/man1/hollywood.1
install -Dm 0644 -t %buildroot/%_datarootdir/hollywood/ share/hollywood/*

install -Dm 0755 bin/wallstreet %buildroot/%_bindir
install -Dm 0755 -t %buildroot/%_libexecdir/wallstreet/ lib/wallstreet/*
install -Dm 0644 -t %buildroot/%_datarootdir/wallstreet share/wallstreet/*

%files
%defattr(-,root,root)
%_bindir/hollywood
%_libexecdir/hollywood/
%_mandir/man1/hollywood.1*

%files data
%defattr(-,root,root)
%_datarootdir/hollywood

%files -n wallstreet
%defattr(-,root,root)
%_bindir/wallstreet
%_libexecdir/wallstreet/
%_datarootdir/wallstreet

%changelog
* Sun Jul 11 2021 Jonathan Papineau <jonathan@jpapineau.ca>
- Add libexec_fix.patch to rewrite module paths from /usr/lib/ to /usr/libexec/
* Fri May  8 2020 Stefan Seyfried <seife+obs@b1-systems.com>
- fix installation after python2 removal:
  * require python3-Pygments instead of python-Pygments
  * do not explicitly require "python" as this is autodetected
* Mon Mar 30 2020 Sebastian Wagner <sebix+novell.com@sebix.at>
  hollywood (1.21) released; urgency=medium
  * === added directory snap.hollywood/local, snap.hollywood/local/0001-
    apg.patch, snap.hollywood/local/0002-byobu-shm.patch,
    snap.hollywood/local/0003-hexdump.patch, snap.hollywood/local/0004-
    man.patch, snap.hollywood/local/setup,
    snap.hollywood/snapcraft.yaml:
  - Use base: core18
  - Move to strict confinement
  - Patch apg to be snap-aware
  - Patch 3 hollywood files to be snap-aware:
  - /dev/shm path
  - man related path
  - paths for hexdump
  - Add command-chain for minor workarounds:
  - BYOBU_PREFIX uses realpath in .byoburc
  - Link czze plugins to the confined home
  * snap.hollywood/snapcraft.yaml:
  - adjusted to build
- update to version 1.20:
  * lib/hollywood/mplayer, share/hollywood/soundwave.mp4:
  - added sound wave video (no sound)
  - start at a random point, between 0 and 99 seconds into the video
  - speed it up 100x
  * debian/control:
  - depends, rather than recommends
  * debian/changelog:
  - fix email
- update to version 1.19:
  * bin/hollywood, debian/control, debian/copyright, lib/hollywood/apg,
    share/hollywood/mi.mp4, share/man/man1/hollywood.1, TODO:
  - Bug deb#944275: remove last remnants of old sound/video plugin
* Thu Oct 24 2019 Sebastian Wagner <sebix+novell.com@sebix.at>
- remove tmux-version-comp.patch not needed anymore
- update to version 1.18:
  * bin/wallstreet, debian/control, lib/wallstreet/newsbeuter =>
    lib/wallstreet/newsboat, lib/wallstreet/ticker, lib/wallstreet/w3m,
    share/wallstreet/newsbeuter.config =>
    share/wallstreet/newsboat.config, share/wallstreet/newsbeuter.urls
    => share/wallstreet/newsboat.urls:
  - Get wallstreet working again
  - move from newsbeuter to newsboat, Closes: deb#914627
  - move from google to yahoo
  - replace rsstail panel
  * bin/wallstreet, share/wallstreet/newsboat.config:
  - drop support for Ubuntu versions before 16.10
  - simplify pane sizing
  - text wrap newsboat at 70 columns
  * debian/changelog:
  - merge in Debian maintainer changelogs, here upstream into this one
- update to version 1.17:
  * No change rebuild
- update to version 1.16:
  * debian/control:
  - added atop
  * bin/hollywood, debian/control, lib/hollywood/apg,
    lib/hollywood/atop, lib/hollywood/bmon, lib/hollywood/cmatrix,
    lib/hollywood/code, lib/hollywood/errno, lib/hollywood/hexdump,
    lib/hollywood/htop, lib/hollywood/jp2a, lib/hollywood/logs,
    lib/hollywood/man, lib/hollywood/mplayer, lib/hollywood/speedometer,
    lib/hollywood/sshart, lib/hollywood/stat, lib/hollywood/tree,
    share/man/man1/hollywood.1:
  - rework the pane reorganization system
    + rather than just using the presets, tear down all panes but one,
    and build them back up
    + adds much more randomness (2^16) and more interesting pane layouts
  - speed up mplayer (when sound is off), makes for a more interesting
    animation
  - add and document a command line option for -d|--delay in seconds,
    for the amount of time between window reorganization
  - simplify the pkill/trap to only catch ctrl-c (SIGINT)
  - loop the mplayer animation, in case the delay is longer than the
    length of the animation
  - reorganize the stat widget, to run head first, then randomize,
    improves start time drammatically
  * lib/hollywood/apg, lib/hollywood/code, lib/hollywood/jp2a,
    lib/hollywood/logs, lib/hollywood/map, lib/hollywood/sshart,
    share/hollywood/map.jpg:
  - randomize the colors on apg
  - use locate -l to stop matching after 4096 files
  - randomize the logs order
  - add a map, because there's always a world map
  * debian/control, debian/copyright, debian/wallstreet.install,
    share/man/man1/wallstreet.1:
  - merge some of the changes from debian
  * share/man/man1/hollywood.1:
  - add link to hollywood.computer
* Sun Jun  2 2019 Jan Engelhardt <jengelh@inai.de>
- Use noun phrase in summary.
* Thu Mar 21 2019 Sebastian Wagner <sebix+novell.com@sebix.at>
- update to version 1.15:
  * README:
  - removed some cruft
  * screenshots/
  - added a screenshots directory
  * bin/hollywood, share/man/man1/hollywood.1:
  - default to nosound, add --sound to enable sound
  - https://github.com/dustinkirkland/hollywood/issues/27
- use HTTPS URL.
* Wed May  2 2018 sebix+novell.com@sebix.at
- update to version 1.14:
  * no revelant changes
- update to version 1.13:
  * lib/wallstreet/w3m:
  - fix Google Finance URL
* Sat Mar 25 2017 sebix+novell.com@sebix.at
- Change License spec "AND" to "and" for compatibility with OpenSUSE Leap 42.3
* Sat Feb 18 2017 sebix+novell.com@sebix.at
- Add CC0 license from subpackage to top package
* Fri Feb  3 2017 jengelh@inai.de
- Set more appropriate RPM group.
  Replace unnecesary %%__install macro by plain install,
  and make all macros have the same style.
* Fri Feb  3 2017 sebix+novell.com@sebix.at
- split media files to hollywood-data
* Mon Dec 26 2016 sebix+novell.com@sebix.at
- initial package
- use tmux-version-comp.patch to patch version comparison with dpkg
